==> haskell-retrie-1.2.3-131-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-retrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 retrie
version:              1.2.3
visibility:           public
id:                   retrie-1.2.3-L4H5e5xcK6b3Dj9yIGffaO
key:                  retrie-1.2.3-L4H5e5xcK6b3Dj9yIGffaO
license:              MIT
copyright:            Copyright (c) Facebook, Inc. and its affiliates.
maintainer:           Andrew Farmer <anfarmer@fb.com>
author:               Andrew Farmer <anfarmer@fb.com>
homepage:             https://github.com/facebookincubator/retrie
synopsis:             A powerful, easy-to-use codemodding tool for Haskell.
description:
    Retrie is a tool for codemodding Haskell. Key goals include:

    * Speed: Efficiently rewrite in large (>1 million line) codebases.
    * Safety: Avoids large classes of codemod-related errors.
    * Ease-of-use: Haskell syntax instead of regular expressions. No hand-rolled AST traversals.

    This package provides a command-line tool (@retrie@) and a library
    ("Retrie") for making equational edits to Haskell code.

    Please see the [README](#readme) for examples and usage.

category:             Development
abi:                  bd257bc93b19c6f777f89f5cf09ca0e4
exposed:              True
exposed-modules:
    Retrie Retrie.AlphaEnv Retrie.CPP Retrie.Context Retrie.Debug
    Retrie.Elaborate Retrie.ExactPrint Retrie.ExactPrint.Annotated
    Retrie.Expr Retrie.Fixity Retrie.FreeVars Retrie.GHC
    Retrie.GroundTerms Retrie.Monad Retrie.Options
    Retrie.PatternMap.Bag Retrie.PatternMap.Class
    Retrie.PatternMap.Instances Retrie.Pretty Retrie.Quantifiers
    Retrie.Query Retrie.Replace Retrie.Rewrites
    Retrie.Rewrites.Function Retrie.Rewrites.Patterns
    Retrie.Rewrites.Rules Retrie.Rewrites.Types Retrie.Run Retrie.SYB
    Retrie.Subst Retrie.Substitution Retrie.Types Retrie.Universe
    Retrie.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/retrie-1.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/retrie-1.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/retrie-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-retrie
hs-libraries:         HSretrie-1.2.3-L4H5e5xcK6b3Dj9yIGffaO
depends:
    ansi-terminal-1.0.2-4v7foyTOWos7vsV6BCUMgI
    async-2.2.5-1XszS28nMj91eBjCxIzBEt base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd directory-1.3.7.1
    filepath-1.4.2.2 ghc-9.4.8
    ghc-exactprint-1.6.1-HYgwJJYigCq8uB7qQukZmU
    list-t-1.0.5.7-EJ3gydpvNy7LFPsItC9ump mtl-2.2.2
    optparse-applicative-0.18.1.0-LLjVXIIvCj2EgCMfmpm2Bg
    process-1.6.18.0 random-shuffle-0.0.4-CozRepQLBNi3YASGVBcVcX
    syb-0.7.3-8mb1dpoCL4AAb4S0Fpw3xy text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-L410VxfvorQ5RMb8wocThG

haddock-interfaces:   /usr/share/doc/haskell-retrie/html/retrie.haddock
haddock-html:         /usr/share/doc/haskell-retrie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-retrie-1.2.3-132-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-retrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 retrie
version:              1.2.3
visibility:           public
id:                   retrie-1.2.3-GPIoVU9VXfACFZRRvzucrf
key:                  retrie-1.2.3-GPIoVU9VXfACFZRRvzucrf
license:              MIT
copyright:            Copyright (c) Facebook, Inc. and its affiliates.
maintainer:           Andrew Farmer <anfarmer@fb.com>
author:               Andrew Farmer <anfarmer@fb.com>
homepage:             https://github.com/facebookincubator/retrie
synopsis:             A powerful, easy-to-use codemodding tool for Haskell.
description:
    Retrie is a tool for codemodding Haskell. Key goals include:

    * Speed: Efficiently rewrite in large (>1 million line) codebases.
    * Safety: Avoids large classes of codemod-related errors.
    * Ease-of-use: Haskell syntax instead of regular expressions. No hand-rolled AST traversals.

    This package provides a command-line tool (@retrie@) and a library
    ("Retrie") for making equational edits to Haskell code.

    Please see the [README](#readme) for examples and usage.

category:             Development
abi:                  41487aa9a8732afa26fa0298726445a3
exposed:              True
exposed-modules:
    Retrie Retrie.AlphaEnv Retrie.CPP Retrie.Context Retrie.Debug
    Retrie.Elaborate Retrie.ExactPrint Retrie.ExactPrint.Annotated
    Retrie.Expr Retrie.Fixity Retrie.FreeVars Retrie.GHC
    Retrie.GroundTerms Retrie.Monad Retrie.Options
    Retrie.PatternMap.Bag Retrie.PatternMap.Class
    Retrie.PatternMap.Instances Retrie.Pretty Retrie.Quantifiers
    Retrie.Query Retrie.Replace Retrie.Rewrites
    Retrie.Rewrites.Function Retrie.Rewrites.Patterns
    Retrie.Rewrites.Rules Retrie.Rewrites.Types Retrie.Run Retrie.SYB
    Retrie.Subst Retrie.Substitution Retrie.Types Retrie.Universe
    Retrie.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/retrie-1.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/retrie-1.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/retrie-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-retrie
hs-libraries:         HSretrie-1.2.3-GPIoVU9VXfACFZRRvzucrf
depends:
    ansi-terminal-1.0.2-JNQYc01xThWEgUAi55dqd4
    async-2.2.5-BbDohv985MkKG2Ydm62Fmc base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd directory-1.3.7.1
    filepath-1.4.2.2 ghc-9.4.8
    ghc-exactprint-1.6.1-3KSW4vPDixo8k8ek87B16X
    list-t-1.0.5.7-GiyCsWRvIJnKJGy8VJpPo5 mtl-2.2.2
    optparse-applicative-0.18.1.0-CZp2uWBrZhVKrqP7dbntdc
    process-1.6.18.0 random-shuffle-0.0.4-KlwOaalsrfrF19jcgCKKDD
    syb-0.7.3-JxKwJKAj8VO69Skm5xz2vL text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-9wNMaDmysQKAAHkxxaXhUB

haddock-interfaces:   /usr/share/doc/haskell-retrie/html/retrie.haddock
haddock-html:         /usr/share/doc/haskell-retrie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
